<?php

namespace strategy\driver;

use strategy\Driver;

if (!function_exists('exif_imagetype')) {
    function exif_imagetype($filename)
    {
        if ((list($width, $height, $type, $attr) = getimagesize($filename)) !== false) {
            return $type;
        }
        return false;
    }
}

/**
 * Aws储存驱动
 *
 * Class Aws
 * @package strategy\driver
 */
class Aws implements Driver
{
    /**
     * 当前储存策略参数
     *
     * @var array
     */
    protected $options = [];

    /**
     * 错误信息
     *
     * @var null
     */
    protected $error = null;

    /**
     * Aws实例
     *
     * @var null
     */
    protected $s3 = null;

    /**
     * Aws constructor.
     *
     * @param array $options
     */
    public function __construct($options = [])
    {
        $this->options = $options;
        try {
            $this->s3 = new \Aws\S3\S3Client([
                'version' => 'latest',
                'region'  => 'us-east-1',
                'endpoint' => $this->options['s3_endpoint'],
                'use_path_style_endpoint' => true,
                'credentials' => [
                    'key'    => $this->options['s3_key'],
                    'secret' => $this->options['s3_secret'],
                ],
            ]);
        } catch (\Exception $e) {
            $this->error = $e->getMessage();
        }
    }

    /**
     * 创建文件
     *
     * @param $pathname
     * @param $file
     *
     * @return bool
     */
    public function create($pathname, $file)
    {
        try {
            $params = array(
                'Bucket' => $this->options['s3_bucket'],
                'Key' => $pathname,
                'Body' => fopen($file, 'rb')
            );
            if ($image_type = exif_imagetype($file)) {
                $params['ContentType'] = image_type_to_mime_type($image_type);
            }

            $this->s3->putObject($params);
        } catch (\Exception $e) {
            $this->error = $e->getMessage();
            return false;
        }

        return true;
    }

    /**
     * 删除文件
     *
     * @param $pathname
     *
     * @return bool
     */
    public function delete($pathname)
    {
        try {
            $this->s3->deleteObject([
                'Bucket' => $this->options['s3_bucket'],
                'Key' => $pathname,
            ]);
        } catch (\Exception $e) {
            $this->error = $e->getMessage();
            return false;
        }

        return true;
    }

    /**
     * 删除多个文件
     *
     * @param array $list
     * @return bool|mixed
     */
    public function deletes(array $list)
    {
        try {
            $objects = [];
            foreach ($list as $value) {
                $objects[] = ['Key' => $value ];
            }
            $this->s3->deleteObjects([
                'Bucket' => $this->options['s3_bucket'],
                'Objects' => $objects,
            ]);
        } catch (\Exception $e) {
            $this->error = $e->getMessage();
            return false;
        }

        return true;
    }

    public function getError()
    {
        return 'Aws：' . $this->error;
    }
}
